# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: preferences/v1/preferences.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='preferences/v1/preferences.proto',
  package='blueapi.preferences.v1',
  syntax='proto3',
  serialized_options=b'\n\035cloud.alphaus.api.preferencesB\020PreferencesProtoZ*github.com/alphauslabs/blueapi/preferences',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n preferences/v1/preferences.proto\x12\x16\x62lueapi.preferences.v1\x1a\x1cgoogle/api/annotations.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"\x0c\n\nPreference\"\x17\n\x15GetPreferencesRequest2\xa5\x02\n\x0bPreferences\x12v\n\x0eGetPreferences\x12-.blueapi.preferences.v1.GetPreferencesRequest\x1a\".blueapi.preferences.v1.Preference\"\x11\x82\xd3\xe4\x93\x02\x0b\x12\t/prefs/v1\x1a\x9d\x01\x92\x41\x99\x01\x12\x42(BETA) Preferences API. Base URL: https://api.alphaus.cloud/m/blue\x1aS\n\x12Service definition\x12=https://github.com/alphauslabs/blueapi/tree/main/preferences/B]\n\x1d\x63loud.alphaus.api.preferencesB\x10PreferencesProtoZ*github.com/alphauslabs/blueapi/preferencesb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,protoc__gen__openapiv2_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_PREFERENCE = _descriptor.Descriptor(
  name='Preference',
  full_name='blueapi.preferences.v1.Preference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=138,
  serialized_end=150,
)


_GETPREFERENCESREQUEST = _descriptor.Descriptor(
  name='GetPreferencesRequest',
  full_name='blueapi.preferences.v1.GetPreferencesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=152,
  serialized_end=175,
)

DESCRIPTOR.message_types_by_name['Preference'] = _PREFERENCE
DESCRIPTOR.message_types_by_name['GetPreferencesRequest'] = _GETPREFERENCESREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Preference = _reflection.GeneratedProtocolMessageType('Preference', (_message.Message,), {
  'DESCRIPTOR' : _PREFERENCE,
  '__module__' : 'preferences.v1.preferences_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.preferences.v1.Preference)
  })
_sym_db.RegisterMessage(Preference)

GetPreferencesRequest = _reflection.GeneratedProtocolMessageType('GetPreferencesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPREFERENCESREQUEST,
  '__module__' : 'preferences.v1.preferences_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.preferences.v1.GetPreferencesRequest)
  })
_sym_db.RegisterMessage(GetPreferencesRequest)


DESCRIPTOR._options = None

_PREFERENCES = _descriptor.ServiceDescriptor(
  name='Preferences',
  full_name='blueapi.preferences.v1.Preferences',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\222A\231\001\022B(BETA) Preferences API. Base URL: https://api.alphaus.cloud/m/blue\032S\n\022Service definition\022=https://github.com/alphauslabs/blueapi/tree/main/preferences/',
  create_key=_descriptor._internal_create_key,
  serialized_start=178,
  serialized_end=471,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetPreferences',
    full_name='blueapi.preferences.v1.Preferences.GetPreferences',
    index=0,
    containing_service=None,
    input_type=_GETPREFERENCESREQUEST,
    output_type=_PREFERENCE,
    serialized_options=b'\202\323\344\223\002\013\022\t/prefs/v1',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_PREFERENCES)

DESCRIPTOR.services_by_name['Preferences'] = _PREFERENCES

# @@protoc_insertion_point(module_scope)
