# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/aws/reduction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/aws/reduction.proto',
  package='blueapi.api.aws',
  syntax='proto3',
  serialized_options=b'\n\035cloud.alphaus.blueapi.api.awsB\024ApiAwsReductionProtoZ*github.com/alphauslabs/blue-sdk-go/api/aws',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17\x61pi/aws/reduction.proto\x12\x0f\x62lueapi.api.aws\"\xc3\x01\n\x11\x41wsCostReductions\x12\x36\n\x07summary\x18\x01 \x01(\x0b\x32%.blueapi.api.aws.CostReductionSummary\x12:\n\x10riCostReductions\x18\x02 \x03(\x0b\x32 .blueapi.api.aws.RiCostReduction\x12:\n\x10spCostReductions\x18\x03 \x03(\x0b\x32 .blueapi.api.aws.SpCostReduction\"\x89\x05\n\x0fRiCostReduction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x12\n\ncustomerId\x18\x03 \x01(\t\x12\x14\n\x0c\x63ustomerName\x18\x04 \x01(\t\x12\x11\n\tcompanyId\x18\x05 \x01(\t\x12\x16\n\x0e\x62illingGroupId\x18\x06 \x01(\t\x12\x18\n\x10\x62illingGroupName\x18\x07 \x01(\t\x12\x16\n\x0e\x64\x65stCustomerId\x18\x08 \x01(\t\x12\r\n\x05start\x18\t \x01(\t\x12\x0b\n\x03\x65nd\x18\n \x01(\t\x12\x0f\n\x07service\x18\x0b \x01(\t\x12\x14\n\x0cinstanceType\x18\x0c \x01(\t\x12\x1a\n\x12modificationStatus\x18\r \x01(\t\x12\x0e\n\x06number\x18\x0e \x01(\x03\x12\x12\n\nofferClass\x18\x0f \x01(\t\x12\x0e\n\x06paidBy\x18\x10 \x01(\t\x12\x15\n\rpaymentOption\x18\x11 \x01(\t\x12\x10\n\x08platform\x18\x12 \x01(\t\x12\x0e\n\x06region\x18\x13 \x01(\t\x12\x0e\n\x06remove\x18\x14 \x01(\t\x12\r\n\x05scope\x18\x15 \x01(\t\x12\x0f\n\x07tenancy\x18\x16 \x01(\t\x12\x12\n\ntermLength\x18\x17 \x01(\t\x12\x11\n\tusageType\x18\x18 \x01(\t\x12\x0e\n\x06vendor\x18\x19 \x01(\t\x12\x0c\n\x04zone\x18\x1a \x01(\t\x12\x10\n\x08\x64isabled\x18\x1b \x01(\t\x12\x1b\n\x13normalizationFactor\x18\x1c \x01(\x01\x12\x15\n\runblendedRate\x18\x1d \x01(\x01\x12\x14\n\x0cupfrontValue\x18\x1e \x01(\x01\x12\x14\n\x0condemandCost\x18\x1f \x01(\x01\x12\x12\n\nactualCost\x18  \x01(\x01\x12\x0f\n\x07savings\x18! \x01(\x01\"\xa6\x03\n\x0fSpCostReduction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x12\n\ncustomerId\x18\x03 \x01(\t\x12\x14\n\x0c\x63ustomerName\x18\x04 \x01(\t\x12\x16\n\x0e\x62illingGroupId\x18\x05 \x01(\t\x12\x18\n\x10\x62illingGroupName\x18\x06 \x01(\t\x12\x10\n\x08\x63urrency\x18\x07 \x01(\t\x12\x0f\n\x07service\x18\x08 \x01(\t\x12\x13\n\x0bsavingsPlan\x18\t \x01(\t\x12\r\n\x05start\x18\n \x01(\t\x12\x0b\n\x03\x65nd\x18\x0b \x01(\t\x12\x0e\n\x06region\x18\x0c \x01(\t\x12\x16\n\x0einstanceFamily\x18\r \x01(\t\x12\x12\n\ntermLength\x18\x0e \x01(\t\x12\x15\n\rpaymentOption\x18\x0f \x01(\t\x12\x12\n\ncommitment\x18\x10 \x01(\x01\x12\x12\n\nupfrontFee\x18\x11 \x01(\x01\x12\x14\n\x0crecurringFee\x18\x12 \x01(\x01\x12\x14\n\x0condemandCost\x18\x13 \x01(\x01\x12\x12\n\nactualCost\x18\x14 \x01(\x01\x12\x0f\n\x07savings\x18\x15 \x01(\x01\"\x80\x02\n\x14\x43ostReductionSummary\x12\x19\n\x11totalOnDemandCost\x18\x01 \x01(\x01\x12\x17\n\x0ftotalActualCost\x18\x02 \x01(\x01\x12\x14\n\x0ctotalSavings\x18\x03 \x01(\x01\x12\x1b\n\x13totalRiOnDemandCost\x18\x04 \x01(\x01\x12\x19\n\x11totalRiActualCost\x18\x05 \x01(\x01\x12\x16\n\x0etotalRiSavings\x18\x06 \x01(\x01\x12\x1b\n\x13totalSpOnDemandCost\x18\x07 \x01(\x01\x12\x19\n\x11totalSpActualCost\x18\x08 \x01(\x01\x12\x16\n\x0etotalSpSavings\x18\t \x01(\x01\x42\x61\n\x1d\x63loud.alphaus.blueapi.api.awsB\x14\x41piAwsReductionProtoZ*github.com/alphauslabs/blue-sdk-go/api/awsb\x06proto3'
)




_AWSCOSTREDUCTIONS = _descriptor.Descriptor(
  name='AwsCostReductions',
  full_name='blueapi.api.aws.AwsCostReductions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='summary', full_name='blueapi.api.aws.AwsCostReductions.summary', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='riCostReductions', full_name='blueapi.api.aws.AwsCostReductions.riCostReductions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spCostReductions', full_name='blueapi.api.aws.AwsCostReductions.spCostReductions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=45,
  serialized_end=240,
)


_RICOSTREDUCTION = _descriptor.Descriptor(
  name='RiCostReduction',
  full_name='blueapi.api.aws.RiCostReduction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.api.aws.RiCostReduction.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arn', full_name='blueapi.api.aws.RiCostReduction.arn', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customerId', full_name='blueapi.api.aws.RiCostReduction.customerId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customerName', full_name='blueapi.api.aws.RiCostReduction.customerName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='companyId', full_name='blueapi.api.aws.RiCostReduction.companyId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billingGroupId', full_name='blueapi.api.aws.RiCostReduction.billingGroupId', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billingGroupName', full_name='blueapi.api.aws.RiCostReduction.billingGroupName', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destCustomerId', full_name='blueapi.api.aws.RiCostReduction.destCustomerId', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='blueapi.api.aws.RiCostReduction.start', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='blueapi.api.aws.RiCostReduction.end', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='blueapi.api.aws.RiCostReduction.service', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instanceType', full_name='blueapi.api.aws.RiCostReduction.instanceType', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modificationStatus', full_name='blueapi.api.aws.RiCostReduction.modificationStatus', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='blueapi.api.aws.RiCostReduction.number', index=13,
      number=14, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offerClass', full_name='blueapi.api.aws.RiCostReduction.offerClass', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paidBy', full_name='blueapi.api.aws.RiCostReduction.paidBy', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paymentOption', full_name='blueapi.api.aws.RiCostReduction.paymentOption', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='platform', full_name='blueapi.api.aws.RiCostReduction.platform', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='blueapi.api.aws.RiCostReduction.region', index=18,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove', full_name='blueapi.api.aws.RiCostReduction.remove', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='blueapi.api.aws.RiCostReduction.scope', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tenancy', full_name='blueapi.api.aws.RiCostReduction.tenancy', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='termLength', full_name='blueapi.api.aws.RiCostReduction.termLength', index=22,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usageType', full_name='blueapi.api.aws.RiCostReduction.usageType', index=23,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vendor', full_name='blueapi.api.aws.RiCostReduction.vendor', index=24,
      number=25, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone', full_name='blueapi.api.aws.RiCostReduction.zone', index=25,
      number=26, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disabled', full_name='blueapi.api.aws.RiCostReduction.disabled', index=26,
      number=27, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='normalizationFactor', full_name='blueapi.api.aws.RiCostReduction.normalizationFactor', index=27,
      number=28, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unblendedRate', full_name='blueapi.api.aws.RiCostReduction.unblendedRate', index=28,
      number=29, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upfrontValue', full_name='blueapi.api.aws.RiCostReduction.upfrontValue', index=29,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ondemandCost', full_name='blueapi.api.aws.RiCostReduction.ondemandCost', index=30,
      number=31, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualCost', full_name='blueapi.api.aws.RiCostReduction.actualCost', index=31,
      number=32, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='savings', full_name='blueapi.api.aws.RiCostReduction.savings', index=32,
      number=33, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=892,
)


_SPCOSTREDUCTION = _descriptor.Descriptor(
  name='SpCostReduction',
  full_name='blueapi.api.aws.SpCostReduction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.api.aws.SpCostReduction.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arn', full_name='blueapi.api.aws.SpCostReduction.arn', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customerId', full_name='blueapi.api.aws.SpCostReduction.customerId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customerName', full_name='blueapi.api.aws.SpCostReduction.customerName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billingGroupId', full_name='blueapi.api.aws.SpCostReduction.billingGroupId', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='billingGroupName', full_name='blueapi.api.aws.SpCostReduction.billingGroupName', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='currency', full_name='blueapi.api.aws.SpCostReduction.currency', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='blueapi.api.aws.SpCostReduction.service', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='savingsPlan', full_name='blueapi.api.aws.SpCostReduction.savingsPlan', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start', full_name='blueapi.api.aws.SpCostReduction.start', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='blueapi.api.aws.SpCostReduction.end', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='blueapi.api.aws.SpCostReduction.region', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instanceFamily', full_name='blueapi.api.aws.SpCostReduction.instanceFamily', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='termLength', full_name='blueapi.api.aws.SpCostReduction.termLength', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paymentOption', full_name='blueapi.api.aws.SpCostReduction.paymentOption', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commitment', full_name='blueapi.api.aws.SpCostReduction.commitment', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upfrontFee', full_name='blueapi.api.aws.SpCostReduction.upfrontFee', index=16,
      number=17, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recurringFee', full_name='blueapi.api.aws.SpCostReduction.recurringFee', index=17,
      number=18, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ondemandCost', full_name='blueapi.api.aws.SpCostReduction.ondemandCost', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actualCost', full_name='blueapi.api.aws.SpCostReduction.actualCost', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='savings', full_name='blueapi.api.aws.SpCostReduction.savings', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=895,
  serialized_end=1317,
)


_COSTREDUCTIONSUMMARY = _descriptor.Descriptor(
  name='CostReductionSummary',
  full_name='blueapi.api.aws.CostReductionSummary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='totalOnDemandCost', full_name='blueapi.api.aws.CostReductionSummary.totalOnDemandCost', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalActualCost', full_name='blueapi.api.aws.CostReductionSummary.totalActualCost', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalSavings', full_name='blueapi.api.aws.CostReductionSummary.totalSavings', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalRiOnDemandCost', full_name='blueapi.api.aws.CostReductionSummary.totalRiOnDemandCost', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalRiActualCost', full_name='blueapi.api.aws.CostReductionSummary.totalRiActualCost', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalRiSavings', full_name='blueapi.api.aws.CostReductionSummary.totalRiSavings', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalSpOnDemandCost', full_name='blueapi.api.aws.CostReductionSummary.totalSpOnDemandCost', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalSpActualCost', full_name='blueapi.api.aws.CostReductionSummary.totalSpActualCost', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='totalSpSavings', full_name='blueapi.api.aws.CostReductionSummary.totalSpSavings', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1320,
  serialized_end=1576,
)

_AWSCOSTREDUCTIONS.fields_by_name['summary'].message_type = _COSTREDUCTIONSUMMARY
_AWSCOSTREDUCTIONS.fields_by_name['riCostReductions'].message_type = _RICOSTREDUCTION
_AWSCOSTREDUCTIONS.fields_by_name['spCostReductions'].message_type = _SPCOSTREDUCTION
DESCRIPTOR.message_types_by_name['AwsCostReductions'] = _AWSCOSTREDUCTIONS
DESCRIPTOR.message_types_by_name['RiCostReduction'] = _RICOSTREDUCTION
DESCRIPTOR.message_types_by_name['SpCostReduction'] = _SPCOSTREDUCTION
DESCRIPTOR.message_types_by_name['CostReductionSummary'] = _COSTREDUCTIONSUMMARY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AwsCostReductions = _reflection.GeneratedProtocolMessageType('AwsCostReductions', (_message.Message,), {
  'DESCRIPTOR' : _AWSCOSTREDUCTIONS,
  '__module__' : 'api.aws.reduction_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.aws.AwsCostReductions)
  })
_sym_db.RegisterMessage(AwsCostReductions)

RiCostReduction = _reflection.GeneratedProtocolMessageType('RiCostReduction', (_message.Message,), {
  'DESCRIPTOR' : _RICOSTREDUCTION,
  '__module__' : 'api.aws.reduction_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.aws.RiCostReduction)
  })
_sym_db.RegisterMessage(RiCostReduction)

SpCostReduction = _reflection.GeneratedProtocolMessageType('SpCostReduction', (_message.Message,), {
  'DESCRIPTOR' : _SPCOSTREDUCTION,
  '__module__' : 'api.aws.reduction_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.aws.SpCostReduction)
  })
_sym_db.RegisterMessage(SpCostReduction)

CostReductionSummary = _reflection.GeneratedProtocolMessageType('CostReductionSummary', (_message.Message,), {
  'DESCRIPTOR' : _COSTREDUCTIONSUMMARY,
  '__module__' : 'api.aws.reduction_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.aws.CostReductionSummary)
  })
_sym_db.RegisterMessage(CostReductionSummary)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
