# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: operations/v1/operations.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from alphausblue.api import operation_pb2 as api_dot_operation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='operations/v1/operations.proto',
  package='blueapi.operations.v1',
  syntax='proto3',
  serialized_options=b'\n\034cloud.alphaus.api.operationsB\017OperationsProtoZ)github.com/alphauslabs/blueapi/operations',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1eoperations/v1/operations.proto\x12\x15\x62lueapi.operations.v1\x1a\x13\x61pi/operation.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"J\n\x15ListOperationsRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x0c\n\x04\x61sOf\x18\x02 \x01(\t\x12\x13\n\x0bincludeDone\x18\x03 \x01(\x08\"#\n\x13GetOperationRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"&\n\x16\x44\x65leteOperationRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"&\n\x16\x43\x61ncelOperationRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"P\n\x14WaitOperationRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x07timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration2\xcc\x05\n\nOperations\x12i\n\x0eListOperations\x12,.blueapi.operations.v1.ListOperationsRequest\x1a\x16.blueapi.api.Operation\"\x0f\x82\xd3\xe4\x93\x02\t\x12\x07/ops/v10\x01\x12j\n\x0cGetOperation\x12*.blueapi.operations.v1.GetOperationRequest\x1a\x16.blueapi.api.Operation\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/ops/v1/{name}\x12p\n\x0f\x44\x65leteOperation\x12-.blueapi.operations.v1.DeleteOperationRequest\x1a\x16.google.protobuf.Empty\"\x16\x82\xd3\xe4\x93\x02\x10*\x0e/ops/v1/{name}\x12z\n\x0f\x43\x61ncelOperation\x12-.blueapi.operations.v1.CancelOperationRequest\x1a\x16.google.protobuf.Empty\" \x82\xd3\xe4\x93\x02\x1a\"\x15/ops/v1/{name}:cancel:\x01*\x12V\n\rWaitOperation\x12+.blueapi.operations.v1.WaitOperationRequest\x1a\x16.blueapi.api.Operation\"\x00\x1a\xa0\x01\x92\x41\x9c\x01\x12\x46(BETA) Long operations API. Base URL: https://api.alphaus.cloud/m/blue\x1aR\n\x12Service definition\x12<https://github.com/alphauslabs/blueapi/tree/main/operations/BZ\n\x1c\x63loud.alphaus.api.operationsB\x0fOperationsProtoZ)github.com/alphauslabs/blueapi/operationsb\x06proto3'
  ,
  dependencies=[api_dot_operation__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,protoc__gen__openapiv2_dot_options_dot_annotations__pb2.DESCRIPTOR,])




_LISTOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListOperationsRequest',
  full_name='blueapi.operations.v1.ListOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='blueapi.operations.v1.ListOperationsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asOf', full_name='blueapi.operations.v1.ListOperationsRequest.asOf', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='includeDone', full_name='blueapi.operations.v1.ListOperationsRequest.includeDone', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=217,
  serialized_end=291,
)


_GETOPERATIONREQUEST = _descriptor.Descriptor(
  name='GetOperationRequest',
  full_name='blueapi.operations.v1.GetOperationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.operations.v1.GetOperationRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=293,
  serialized_end=328,
)


_DELETEOPERATIONREQUEST = _descriptor.Descriptor(
  name='DeleteOperationRequest',
  full_name='blueapi.operations.v1.DeleteOperationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.operations.v1.DeleteOperationRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=368,
)


_CANCELOPERATIONREQUEST = _descriptor.Descriptor(
  name='CancelOperationRequest',
  full_name='blueapi.operations.v1.CancelOperationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.operations.v1.CancelOperationRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=370,
  serialized_end=408,
)


_WAITOPERATIONREQUEST = _descriptor.Descriptor(
  name='WaitOperationRequest',
  full_name='blueapi.operations.v1.WaitOperationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='blueapi.operations.v1.WaitOperationRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='blueapi.operations.v1.WaitOperationRequest.timeout', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=410,
  serialized_end=490,
)

_WAITOPERATIONREQUEST.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name['ListOperationsRequest'] = _LISTOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['GetOperationRequest'] = _GETOPERATIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteOperationRequest'] = _DELETEOPERATIONREQUEST
DESCRIPTOR.message_types_by_name['CancelOperationRequest'] = _CANCELOPERATIONREQUEST
DESCRIPTOR.message_types_by_name['WaitOperationRequest'] = _WAITOPERATIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListOperationsRequest = _reflection.GeneratedProtocolMessageType('ListOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTOPERATIONSREQUEST,
  '__module__' : 'operations.v1.operations_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.operations.v1.ListOperationsRequest)
  })
_sym_db.RegisterMessage(ListOperationsRequest)

GetOperationRequest = _reflection.GeneratedProtocolMessageType('GetOperationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOPERATIONREQUEST,
  '__module__' : 'operations.v1.operations_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.operations.v1.GetOperationRequest)
  })
_sym_db.RegisterMessage(GetOperationRequest)

DeleteOperationRequest = _reflection.GeneratedProtocolMessageType('DeleteOperationRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEOPERATIONREQUEST,
  '__module__' : 'operations.v1.operations_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.operations.v1.DeleteOperationRequest)
  })
_sym_db.RegisterMessage(DeleteOperationRequest)

CancelOperationRequest = _reflection.GeneratedProtocolMessageType('CancelOperationRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELOPERATIONREQUEST,
  '__module__' : 'operations.v1.operations_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.operations.v1.CancelOperationRequest)
  })
_sym_db.RegisterMessage(CancelOperationRequest)

WaitOperationRequest = _reflection.GeneratedProtocolMessageType('WaitOperationRequest', (_message.Message,), {
  'DESCRIPTOR' : _WAITOPERATIONREQUEST,
  '__module__' : 'operations.v1.operations_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.operations.v1.WaitOperationRequest)
  })
_sym_db.RegisterMessage(WaitOperationRequest)


DESCRIPTOR._options = None

_OPERATIONS = _descriptor.ServiceDescriptor(
  name='Operations',
  full_name='blueapi.operations.v1.Operations',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\222A\234\001\022F(BETA) Long operations API. Base URL: https://api.alphaus.cloud/m/blue\032R\n\022Service definition\022<https://github.com/alphauslabs/blueapi/tree/main/operations/',
  create_key=_descriptor._internal_create_key,
  serialized_start=493,
  serialized_end=1209,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='blueapi.operations.v1.Operations.ListOperations',
    index=0,
    containing_service=None,
    input_type=_LISTOPERATIONSREQUEST,
    output_type=api_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\t\022\007/ops/v1',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetOperation',
    full_name='blueapi.operations.v1.Operations.GetOperation',
    index=1,
    containing_service=None,
    input_type=_GETOPERATIONREQUEST,
    output_type=api_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\020\022\016/ops/v1/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteOperation',
    full_name='blueapi.operations.v1.Operations.DeleteOperation',
    index=2,
    containing_service=None,
    input_type=_DELETEOPERATIONREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\020*\016/ops/v1/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelOperation',
    full_name='blueapi.operations.v1.Operations.CancelOperation',
    index=3,
    containing_service=None,
    input_type=_CANCELOPERATIONREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\032\"\025/ops/v1/{name}:cancel:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WaitOperation',
    full_name='blueapi.operations.v1.Operations.WaitOperation',
    index=4,
    containing_service=None,
    input_type=_WAITOPERATIONREQUEST,
    output_type=api_dot_operation__pb2._OPERATION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_OPERATIONS)

DESCRIPTOR.services_by_name['Operations'] = _OPERATIONS

# @@protoc_insertion_point(module_scope)
