# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/budget.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/budget.proto',
  package='blueapi.api',
  syntax='proto3',
  serialized_options=b'\n\031cloud.alphaus.blueapi.apiB\016ApiBudgetProtoZ&github.com/alphauslabs/blue-sdk-go/api',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10\x61pi/budget.proto\x12\x0b\x62lueapi.api\"[\n\x06\x42udget\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nfiscalYear\x18\x02 \x01(\t\x12\x31\n\rmonthlyBudget\x18\x03 \x03(\x0b\x32\x1a.blueapi.api.MonthlyBudget\"2\n\rMonthlyBudget\x12\x11\n\tyearMonth\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x42S\n\x19\x63loud.alphaus.blueapi.apiB\x0e\x41piBudgetProtoZ&github.com/alphauslabs/blue-sdk-go/apib\x06proto3'
)




_BUDGET = _descriptor.Descriptor(
  name='Budget',
  full_name='blueapi.api.Budget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='blueapi.api.Budget.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fiscalYear', full_name='blueapi.api.Budget.fiscalYear', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='monthlyBudget', full_name='blueapi.api.Budget.monthlyBudget', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33,
  serialized_end=124,
)


_MONTHLYBUDGET = _descriptor.Descriptor(
  name='MonthlyBudget',
  full_name='blueapi.api.MonthlyBudget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='yearMonth', full_name='blueapi.api.MonthlyBudget.yearMonth', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='blueapi.api.MonthlyBudget.amount', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=176,
)

_BUDGET.fields_by_name['monthlyBudget'].message_type = _MONTHLYBUDGET
DESCRIPTOR.message_types_by_name['Budget'] = _BUDGET
DESCRIPTOR.message_types_by_name['MonthlyBudget'] = _MONTHLYBUDGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Budget = _reflection.GeneratedProtocolMessageType('Budget', (_message.Message,), {
  'DESCRIPTOR' : _BUDGET,
  '__module__' : 'api.budget_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.Budget)
  })
_sym_db.RegisterMessage(Budget)

MonthlyBudget = _reflection.GeneratedProtocolMessageType('MonthlyBudget', (_message.Message,), {
  'DESCRIPTOR' : _MONTHLYBUDGET,
  '__module__' : 'api.budget_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.MonthlyBudget)
  })
_sym_db.RegisterMessage(MonthlyBudget)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
