# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: api/forecast.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='api/forecast.proto',
  package='blueapi.api',
  syntax='proto3',
  serialized_options=b'\n\031cloud.alphaus.blueapi.apiB\020ApiForecastProtoZ&github.com/alphauslabs/blue-sdk-go/api',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12\x61pi/forecast.proto\x12\x0b\x62lueapi.api\"\xc8\x01\n\x0c\x46orecastData\x12\x11\n\taccountId\x18\x01 \x01(\t\x12\x17\n\x0fproductCategory\x18\x02 \x01(\t\x12\x13\n\x0bproductCode\x18\x03 \x01(\t\x12\x11\n\tfrequency\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x05 \x01(\t\x12\x16\n\x0ehistoricalCost\x18\x06 \x01(\x01\x12\x16\n\x0e\x66orecastedCost\x18\x07 \x01(\x01\x12\x12\n\nupperBound\x18\x08 \x01(\x01\x12\x12\n\nlowerBound\x18\t \x01(\x01\"P\n\x14\x41\x63\x63ountGroupForecast\x12\x0f\n\x07groupId\x18\x01 \x01(\t\x12\'\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x19.blueapi.api.ForecastData\"R\n\x14\x42illingGroupForecast\x12\x11\n\tcompanyId\x18\x01 \x01(\t\x12\'\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x19.blueapi.api.ForecastData\"M\n\x0bOrgForecast\x12\r\n\x05orgId\x18\x01 \x01(\t\x12/\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32!.blueapi.api.BillingGroupForecast\"\xa7\x01\n\x17MonthToDateForecastData\x12\x11\n\taccountId\x18\x01 \x01(\t\x12\x17\n\x0fproductCategory\x18\x02 \x01(\t\x12\x13\n\x0bproductCode\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x04 \x01(\t\x12\x17\n\x0f\x61\x63\x63umulatedCost\x18\x05 \x01(\x01\x12\x14\n\x0c\x66orecastCost\x18\x06 \x01(\x01\x12\x0e\n\x06\x62udget\x18\x07 \x01(\x01\"h\n\x1f\x42illingGroupMonthToDateForecast\x12\x11\n\tcompanyId\x18\x01 \x01(\t\x12\x32\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32$.blueapi.api.MonthToDateForecastData\"c\n\x16OrgMonthToDateForecast\x12\r\n\x05orgId\x18\x01 \x01(\t\x12:\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32,.blueapi.api.BillingGroupMonthToDateForecast\"\x85\x01\n\x13MonthlyCostForecast\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\x12\x12\n\ncostActual\x18\x02 \x01(\x01\x12\x14\n\x0c\x63ostForecast\x18\x03 \x01(\x01\x12\x0e\n\x06\x62udget\x18\x04 \x01(\x01\x12\x12\n\nupperBound\x18\x05 \x01(\x01\x12\x12\n\nlowerBound\x18\x06 \x01(\x01\"i\n\x18MonthOnMonthCostForecast\x12\x10\n\x08\x63\x61tegory\x18\x01 \x01(\t\x12\x13\n\x0b\x63ostCurrent\x18\x02 \x01(\x01\x12\x10\n\x08\x63ostPrev\x18\x03 \x01(\x01\x12\x14\n\x0c\x63ostForecast\x18\x04 \x01(\x01\"\x90\x01\n\x17MonthToDateCostForecast\x12\x0c\n\x04\x64\x61te\x18\x01 \x01(\t\x12\x10\n\x08\x63ostPrev\x18\x02 \x01(\x01\x12\x17\n\x0f\x63ostAccumulated\x18\x03 \x01(\x01\x12\x14\n\x0c\x63ostForecast\x18\x04 \x01(\x01\x12\x12\n\nupperBound\x18\x05 \x01(\x01\x12\x12\n\nlowerBound\x18\x06 \x01(\x01\x42U\n\x19\x63loud.alphaus.blueapi.apiB\x10\x41piForecastProtoZ&github.com/alphauslabs/blue-sdk-go/apib\x06proto3'
)




_FORECASTDATA = _descriptor.Descriptor(
  name='ForecastData',
  full_name='blueapi.api.ForecastData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountId', full_name='blueapi.api.ForecastData.accountId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='productCategory', full_name='blueapi.api.ForecastData.productCategory', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='productCode', full_name='blueapi.api.ForecastData.productCode', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='blueapi.api.ForecastData.frequency', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='blueapi.api.ForecastData.date', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='historicalCost', full_name='blueapi.api.ForecastData.historicalCost', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forecastedCost', full_name='blueapi.api.ForecastData.forecastedCost', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upperBound', full_name='blueapi.api.ForecastData.upperBound', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lowerBound', full_name='blueapi.api.ForecastData.lowerBound', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=236,
)


_ACCOUNTGROUPFORECAST = _descriptor.Descriptor(
  name='AccountGroupForecast',
  full_name='blueapi.api.AccountGroupForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupId', full_name='blueapi.api.AccountGroupForecast.groupId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='blueapi.api.AccountGroupForecast.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=318,
)


_BILLINGGROUPFORECAST = _descriptor.Descriptor(
  name='BillingGroupForecast',
  full_name='blueapi.api.BillingGroupForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='companyId', full_name='blueapi.api.BillingGroupForecast.companyId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='blueapi.api.BillingGroupForecast.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=402,
)


_ORGFORECAST = _descriptor.Descriptor(
  name='OrgForecast',
  full_name='blueapi.api.OrgForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orgId', full_name='blueapi.api.OrgForecast.orgId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='blueapi.api.OrgForecast.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=404,
  serialized_end=481,
)


_MONTHTODATEFORECASTDATA = _descriptor.Descriptor(
  name='MonthToDateForecastData',
  full_name='blueapi.api.MonthToDateForecastData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountId', full_name='blueapi.api.MonthToDateForecastData.accountId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='productCategory', full_name='blueapi.api.MonthToDateForecastData.productCategory', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='productCode', full_name='blueapi.api.MonthToDateForecastData.productCode', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date', full_name='blueapi.api.MonthToDateForecastData.date', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accumulatedCost', full_name='blueapi.api.MonthToDateForecastData.accumulatedCost', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forecastCost', full_name='blueapi.api.MonthToDateForecastData.forecastCost', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='budget', full_name='blueapi.api.MonthToDateForecastData.budget', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=484,
  serialized_end=651,
)


_BILLINGGROUPMONTHTODATEFORECAST = _descriptor.Descriptor(
  name='BillingGroupMonthToDateForecast',
  full_name='blueapi.api.BillingGroupMonthToDateForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='companyId', full_name='blueapi.api.BillingGroupMonthToDateForecast.companyId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='blueapi.api.BillingGroupMonthToDateForecast.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=653,
  serialized_end=757,
)


_ORGMONTHTODATEFORECAST = _descriptor.Descriptor(
  name='OrgMonthToDateForecast',
  full_name='blueapi.api.OrgMonthToDateForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orgId', full_name='blueapi.api.OrgMonthToDateForecast.orgId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='blueapi.api.OrgMonthToDateForecast.data', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=759,
  serialized_end=858,
)


_MONTHLYCOSTFORECAST = _descriptor.Descriptor(
  name='MonthlyCostForecast',
  full_name='blueapi.api.MonthlyCostForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='blueapi.api.MonthlyCostForecast.date', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='costActual', full_name='blueapi.api.MonthlyCostForecast.costActual', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='costForecast', full_name='blueapi.api.MonthlyCostForecast.costForecast', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='budget', full_name='blueapi.api.MonthlyCostForecast.budget', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upperBound', full_name='blueapi.api.MonthlyCostForecast.upperBound', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lowerBound', full_name='blueapi.api.MonthlyCostForecast.lowerBound', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=861,
  serialized_end=994,
)


_MONTHONMONTHCOSTFORECAST = _descriptor.Descriptor(
  name='MonthOnMonthCostForecast',
  full_name='blueapi.api.MonthOnMonthCostForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='category', full_name='blueapi.api.MonthOnMonthCostForecast.category', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='costCurrent', full_name='blueapi.api.MonthOnMonthCostForecast.costCurrent', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='costPrev', full_name='blueapi.api.MonthOnMonthCostForecast.costPrev', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='costForecast', full_name='blueapi.api.MonthOnMonthCostForecast.costForecast', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=996,
  serialized_end=1101,
)


_MONTHTODATECOSTFORECAST = _descriptor.Descriptor(
  name='MonthToDateCostForecast',
  full_name='blueapi.api.MonthToDateCostForecast',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='blueapi.api.MonthToDateCostForecast.date', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='costPrev', full_name='blueapi.api.MonthToDateCostForecast.costPrev', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='costAccumulated', full_name='blueapi.api.MonthToDateCostForecast.costAccumulated', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='costForecast', full_name='blueapi.api.MonthToDateCostForecast.costForecast', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upperBound', full_name='blueapi.api.MonthToDateCostForecast.upperBound', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lowerBound', full_name='blueapi.api.MonthToDateCostForecast.lowerBound', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1104,
  serialized_end=1248,
)

_ACCOUNTGROUPFORECAST.fields_by_name['data'].message_type = _FORECASTDATA
_BILLINGGROUPFORECAST.fields_by_name['data'].message_type = _FORECASTDATA
_ORGFORECAST.fields_by_name['data'].message_type = _BILLINGGROUPFORECAST
_BILLINGGROUPMONTHTODATEFORECAST.fields_by_name['data'].message_type = _MONTHTODATEFORECASTDATA
_ORGMONTHTODATEFORECAST.fields_by_name['data'].message_type = _BILLINGGROUPMONTHTODATEFORECAST
DESCRIPTOR.message_types_by_name['ForecastData'] = _FORECASTDATA
DESCRIPTOR.message_types_by_name['AccountGroupForecast'] = _ACCOUNTGROUPFORECAST
DESCRIPTOR.message_types_by_name['BillingGroupForecast'] = _BILLINGGROUPFORECAST
DESCRIPTOR.message_types_by_name['OrgForecast'] = _ORGFORECAST
DESCRIPTOR.message_types_by_name['MonthToDateForecastData'] = _MONTHTODATEFORECASTDATA
DESCRIPTOR.message_types_by_name['BillingGroupMonthToDateForecast'] = _BILLINGGROUPMONTHTODATEFORECAST
DESCRIPTOR.message_types_by_name['OrgMonthToDateForecast'] = _ORGMONTHTODATEFORECAST
DESCRIPTOR.message_types_by_name['MonthlyCostForecast'] = _MONTHLYCOSTFORECAST
DESCRIPTOR.message_types_by_name['MonthOnMonthCostForecast'] = _MONTHONMONTHCOSTFORECAST
DESCRIPTOR.message_types_by_name['MonthToDateCostForecast'] = _MONTHTODATECOSTFORECAST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ForecastData = _reflection.GeneratedProtocolMessageType('ForecastData', (_message.Message,), {
  'DESCRIPTOR' : _FORECASTDATA,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.ForecastData)
  })
_sym_db.RegisterMessage(ForecastData)

AccountGroupForecast = _reflection.GeneratedProtocolMessageType('AccountGroupForecast', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGROUPFORECAST,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.AccountGroupForecast)
  })
_sym_db.RegisterMessage(AccountGroupForecast)

BillingGroupForecast = _reflection.GeneratedProtocolMessageType('BillingGroupForecast', (_message.Message,), {
  'DESCRIPTOR' : _BILLINGGROUPFORECAST,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.BillingGroupForecast)
  })
_sym_db.RegisterMessage(BillingGroupForecast)

OrgForecast = _reflection.GeneratedProtocolMessageType('OrgForecast', (_message.Message,), {
  'DESCRIPTOR' : _ORGFORECAST,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.OrgForecast)
  })
_sym_db.RegisterMessage(OrgForecast)

MonthToDateForecastData = _reflection.GeneratedProtocolMessageType('MonthToDateForecastData', (_message.Message,), {
  'DESCRIPTOR' : _MONTHTODATEFORECASTDATA,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.MonthToDateForecastData)
  })
_sym_db.RegisterMessage(MonthToDateForecastData)

BillingGroupMonthToDateForecast = _reflection.GeneratedProtocolMessageType('BillingGroupMonthToDateForecast', (_message.Message,), {
  'DESCRIPTOR' : _BILLINGGROUPMONTHTODATEFORECAST,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.BillingGroupMonthToDateForecast)
  })
_sym_db.RegisterMessage(BillingGroupMonthToDateForecast)

OrgMonthToDateForecast = _reflection.GeneratedProtocolMessageType('OrgMonthToDateForecast', (_message.Message,), {
  'DESCRIPTOR' : _ORGMONTHTODATEFORECAST,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.OrgMonthToDateForecast)
  })
_sym_db.RegisterMessage(OrgMonthToDateForecast)

MonthlyCostForecast = _reflection.GeneratedProtocolMessageType('MonthlyCostForecast', (_message.Message,), {
  'DESCRIPTOR' : _MONTHLYCOSTFORECAST,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.MonthlyCostForecast)
  })
_sym_db.RegisterMessage(MonthlyCostForecast)

MonthOnMonthCostForecast = _reflection.GeneratedProtocolMessageType('MonthOnMonthCostForecast', (_message.Message,), {
  'DESCRIPTOR' : _MONTHONMONTHCOSTFORECAST,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.MonthOnMonthCostForecast)
  })
_sym_db.RegisterMessage(MonthOnMonthCostForecast)

MonthToDateCostForecast = _reflection.GeneratedProtocolMessageType('MonthToDateCostForecast', (_message.Message,), {
  'DESCRIPTOR' : _MONTHTODATECOSTFORECAST,
  '__module__' : 'api.forecast_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.api.MonthToDateCostForecast)
  })
_sym_db.RegisterMessage(MonthToDateCostForecast)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
