# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kvstore/v1/kvstore.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kvstore/v1/kvstore.proto',
  package='blueapi.kvstore.v1',
  syntax='proto3',
  serialized_options=b'\n\031cloud.alphaus.api.kvstoreB\014KvStoreProtoZ&github.com/alphauslabs/blueapi/kvstore',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18kvstore/v1/kvstore.proto\x12\x12\x62lueapi.kvstore.v1\x1a\x1cgoogle/api/annotations.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\"&\n\x08KeyValue\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x1b\n\x0bScanRequest\x12\x0c\n\x04like\x18\x01 \x01(\t\"\x1a\n\x0bReadRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\"\x1c\n\rDeleteRequest\x12\x0b\n\x03key\x18\x01 \x01(\t2\x8a\x04\n\x07KvStore\x12Y\n\x04Scan\x12\x1f.blueapi.kvstore.v1.ScanRequest\x1a\x1c.blueapi.kvstore.v1.KeyValue\"\x10\x82\xd3\xe4\x93\x02\n\x12\x08/v1/keys0\x01\x12]\n\x04Read\x12\x1f.blueapi.kvstore.v1.ReadRequest\x1a\x1c.blueapi.kvstore.v1.KeyValue\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/keys/{key}\x12M\n\x05Write\x12\x1c.blueapi.kvstore.v1.KeyValue\x1a\x16.google.protobuf.Empty\"\x0e\x82\xd3\xe4\x93\x02\x08\"\x03/v1:\x01*\x12[\n\x06\x44\x65lete\x12!.blueapi.kvstore.v1.DeleteRequest\x1a\x16.google.protobuf.Empty\"\x16\x82\xd3\xe4\x93\x02\x10*\x0e/v1/keys/{key}\x1a\x98\x01\x92\x41\x94\x01\x12\x41(BETA) KvStore API. Base URL: https://api.alphaus.cloud/m/blue/kv\x1aO\n\x12Service definition\x12\x39https://github.com/alphauslabs/blueapi/tree/main/kvstore/BQ\n\x19\x63loud.alphaus.api.kvstoreB\x0cKvStoreProtoZ&github.com/alphauslabs/blueapi/kvstoreb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,protoc__gen__openapiv2_dot_options_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_KEYVALUE = _descriptor.Descriptor(
  name='KeyValue',
  full_name='blueapi.kvstore.v1.KeyValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='blueapi.kvstore.v1.KeyValue.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='blueapi.kvstore.v1.KeyValue.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=193,
)


_SCANREQUEST = _descriptor.Descriptor(
  name='ScanRequest',
  full_name='blueapi.kvstore.v1.ScanRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='like', full_name='blueapi.kvstore.v1.ScanRequest.like', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=195,
  serialized_end=222,
)


_READREQUEST = _descriptor.Descriptor(
  name='ReadRequest',
  full_name='blueapi.kvstore.v1.ReadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='blueapi.kvstore.v1.ReadRequest.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=250,
)


_DELETEREQUEST = _descriptor.Descriptor(
  name='DeleteRequest',
  full_name='blueapi.kvstore.v1.DeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='blueapi.kvstore.v1.DeleteRequest.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=280,
)

DESCRIPTOR.message_types_by_name['KeyValue'] = _KEYVALUE
DESCRIPTOR.message_types_by_name['ScanRequest'] = _SCANREQUEST
DESCRIPTOR.message_types_by_name['ReadRequest'] = _READREQUEST
DESCRIPTOR.message_types_by_name['DeleteRequest'] = _DELETEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeyValue = _reflection.GeneratedProtocolMessageType('KeyValue', (_message.Message,), {
  'DESCRIPTOR' : _KEYVALUE,
  '__module__' : 'kvstore.v1.kvstore_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.kvstore.v1.KeyValue)
  })
_sym_db.RegisterMessage(KeyValue)

ScanRequest = _reflection.GeneratedProtocolMessageType('ScanRequest', (_message.Message,), {
  'DESCRIPTOR' : _SCANREQUEST,
  '__module__' : 'kvstore.v1.kvstore_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.kvstore.v1.ScanRequest)
  })
_sym_db.RegisterMessage(ScanRequest)

ReadRequest = _reflection.GeneratedProtocolMessageType('ReadRequest', (_message.Message,), {
  'DESCRIPTOR' : _READREQUEST,
  '__module__' : 'kvstore.v1.kvstore_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.kvstore.v1.ReadRequest)
  })
_sym_db.RegisterMessage(ReadRequest)

DeleteRequest = _reflection.GeneratedProtocolMessageType('DeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREQUEST,
  '__module__' : 'kvstore.v1.kvstore_pb2'
  # @@protoc_insertion_point(class_scope:blueapi.kvstore.v1.DeleteRequest)
  })
_sym_db.RegisterMessage(DeleteRequest)


DESCRIPTOR._options = None

_KVSTORE = _descriptor.ServiceDescriptor(
  name='KvStore',
  full_name='blueapi.kvstore.v1.KvStore',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\222A\224\001\022A(BETA) KvStore API. Base URL: https://api.alphaus.cloud/m/blue/kv\032O\n\022Service definition\0229https://github.com/alphauslabs/blueapi/tree/main/kvstore/',
  create_key=_descriptor._internal_create_key,
  serialized_start=283,
  serialized_end=805,
  methods=[
  _descriptor.MethodDescriptor(
    name='Scan',
    full_name='blueapi.kvstore.v1.KvStore.Scan',
    index=0,
    containing_service=None,
    input_type=_SCANREQUEST,
    output_type=_KEYVALUE,
    serialized_options=b'\202\323\344\223\002\n\022\010/v1/keys',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Read',
    full_name='blueapi.kvstore.v1.KvStore.Read',
    index=1,
    containing_service=None,
    input_type=_READREQUEST,
    output_type=_KEYVALUE,
    serialized_options=b'\202\323\344\223\002\020\022\016/v1/keys/{key}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Write',
    full_name='blueapi.kvstore.v1.KvStore.Write',
    index=2,
    containing_service=None,
    input_type=_KEYVALUE,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\010\"\003/v1:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='blueapi.kvstore.v1.KvStore.Delete',
    index=3,
    containing_service=None,
    input_type=_DELETEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\202\323\344\223\002\020*\016/v1/keys/{key}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_KVSTORE)

DESCRIPTOR.services_by_name['KvStore'] = _KVSTORE

# @@protoc_insertion_point(module_scope)
